@@ -20,7 +20,7 @@ class Divergence:
 
 		if self.args.inifile:
 			# create Configuration instance and register config option.
-			conf = self.getConfigIns()
+			conf = self.getConfigIns(self.args.inifile)
 			fo = open(".gaeinit.gis", "w")
 			pickle.dump(conf, fo)
 
@@ -42,7 +42,7 @@ class Divergence:
 			indexyaml = self.makefile("index.yaml", self.conf.encoding, INDEX_YAML_TEMP)
 			mainscript = self.makefile(self.conf.mainscript, self.conf.encoding, self.addUserModules(MAIN_SCRIPT_TEMP))
 			webapp  = self.makefile("webapp.py", self.conf.encoding, WEBHANDLER_TEMP)
-#			compiled = self.makefile(".%s.gis", "utf-8", 
+			datastore = self.makefile("datastore.py", self.conf.encoding, DATASTORE_TEMP % self.makeDBsetting())
 
 			# make init directories
 			if self.conf.directories != None:
@@ -71,6 +71,19 @@ class Divergence:
 			filepath = self.makepath(self.args.filepath)
 			self.makefile(filepath, "utf-8", self.addUserModules(NOMAL_SCRIPT_TEMP))
 
+		elif self.args.configfile:
+			conf = self.getConfigIns(self.args.configfile)
+			fo = open(".gaeinit.gis", "w")
+			pickle.dump(conf, fo)
+			fo.close()
+
+			self.conf = loadConfig()
+			if os.getcwd().split("/")[-1] == self.conf.appname:
+				datastore = self.makefile("datastore.py", self.conf.encoding, DATASTORE_TEMP % self.makeDBsetting())
+			else:
+				os.chdir(self.conf.appname)
+				datastore = self.makefile("datastore.py", self.conf.encoding, DATASTORE_TEMP % self.makeDBsetting())
+
 		elif self.args.configtemp:
 			self.makefile("template-config.ini", "utf-8", CONFIG_TEMP)
 		
@@ -81,15 +94,16 @@ class Divergence:
 			else:
 				os.system("appcfg.py update %s" % self.conf.appname)
 
-	def getConfigIns(self):
+	def getConfigIns(self, inifile):
 		# check exist
-		isexist = os.access(self.args.inifile, os.F_OK)
+		isexist = os.access(inifile, os.F_OK)
 		if isexist:
 			parser = ConfigParser()
-			parser.read(self.args.inifile)
+			parser.read(inifile)
 			app = parser._sections["application settings"]
 			file = parser._sections["file settings"]
 			modules = parser._sections["modules import"] if parser.has_section("modules import") else None
+			dbname = parser._sections["database"] if parser.has_section("database") else None
 
 			conf = Configuration()
 			conf.appname = app["appname"]
@@ -98,6 +112,7 @@ class Divergence:
 			conf.encoding = file["encoding"]
 			conf.directories = self.getListFromPat(file["directories"]) if parser.has_option("file settings", "directories") else None
 			conf.modules = self.getListFromPat(modules["modules"]) if parser.has_option("modules import", "modules") else None
+			conf.dbname = self.getListFromPat(dbname["dbname"]) if parser.has_option("database", "dbname") else None
 			return conf
 
 		else:
@@ -138,6 +153,14 @@ class Divergence:
 			template = template.replace("(user_modules)", moduleString)
 			return template
 
+	def makeDBsetting(self):
+		result = {"datastores":""}
+		return_strs = ""
+		for db in self.conf.dbname:
+			return_strs += "class %s(db.Models):\n\t# define datastore property\n\n" % db
+		result["datastores"] = return_strs
+		return result
+
 class Configuration(object):
 	appname = None
 	mainscript = None
@@ -145,6 +168,7 @@ class Configuration(object):
 	encoding = None
 	directories = None
 	modules = None
+	dbname = None
 
 
 def loadConfig():
